'use client';
import { jsx as _jsx } from "react/jsx-runtime";
import * as React from 'react';
import { List } from "../../../List/index.js";
import { SelectQa, selectListBlock } from "../../constants.js";
import { getOptionsHeight, getPopupItemHeight, scrollToItem } from "../../utils.js";
import { GroupLabel } from "./GroupLabel.js";
import { OptionWrap } from "./OptionWrap.js";
import { SelectLoadingIndicator } from "./SelectLoadingIndicator.js";
import "./SelectList.css";
const loadingOption = { value: '__SELECT_LIST_ITEM_LOADING__', disabled: true };
export const SelectList = React.forwardRef((props, ref) => {
    const { onOptionClick, renderOption, renderOptionGroup, getOptionHeight, getOptionGroupHeight, size, flattenOptions, value, multiple, virtualized, mobile, loading, onLoadMore, id, activeIndex, onChangeActive, } = props;
    const items = React.useMemo(() => (loading ? [...flattenOptions, loadingOption] : flattenOptions), [flattenOptions, loading]);
    const selectedIndexes = React.useMemo(() => flattenOptions.reduce((acc, option, index) => {
        if ('value' in option && value.includes(option.value)) {
            acc.push(index);
        }
        return acc;
    }, []), [flattenOptions, value]);
    const optionsHeight = getOptionsHeight({
        options: items,
        getOptionHeight,
        getOptionGroupHeight,
        size,
        mobile,
    });
    const getItemHeight = React.useCallback((option, index) => {
        return getPopupItemHeight({
            getOptionHeight,
            getOptionGroupHeight,
            size,
            option,
            index,
            mobile,
        });
    }, [getOptionHeight, getOptionGroupHeight, mobile, size]);
    const renderItem = React.useCallback((option, _isItemActive, itemIndex) => {
        if ('label' in option) {
            const wrappedRenderOptionGroup = renderOptionGroup
                ? (optionLocal) => {
                    return renderOptionGroup(optionLocal, {
                        itemHeight: getItemHeight(optionLocal, itemIndex),
                    });
                }
                : undefined;
            return _jsx(GroupLabel, { option: option, renderOptionGroup: wrappedRenderOptionGroup });
        }
        if (option.value === loadingOption.value) {
            return (_jsx(SelectLoadingIndicator, { onIntersect: itemIndex === 0 ? undefined : onLoadMore }));
        }
        const wrappedRenderOption = renderOption
            ? (optionLocal) => {
                return renderOption(optionLocal, {
                    itemHeight: getItemHeight(optionLocal, itemIndex),
                });
            }
            : undefined;
        return (_jsx(OptionWrap, { option: option, value: value, multiple: multiple, renderOption: wrappedRenderOption }));
    }, [renderOption, renderOptionGroup, value, multiple, getItemHeight, onLoadMore]);
    return (_jsx(List, { ref: ref, className: selectListBlock({ size, virtualized, mobile }), qa: SelectQa.LIST, itemClassName: selectListBlock('item'), itemHeight: getItemHeight, itemsHeight: virtualized ? optionsHeight : undefined, items: items, filterable: false, virtualized: virtualized, renderItem: renderItem, onItemClick: onOptionClick, selectedItemIndex: selectedIndexes, id: id, role: "listbox", activeItemIndex: activeIndex, onChangeActive: onChangeActive, deactivateOnLeave: false, onScrollToItem: scrollToItem }));
});
SelectList.displayName = 'SelectList';
//# sourceMappingURL=SelectList.js.map
