import { i18n } from "./i18n.js";
/**
 * Add keysets data for a specific language
 *
 * @param language - language code
 * @param data - keyset data
 * @returns void
 *
 * @example
 * import {addLanguageKeysets} from '@gravity-ui/uikit/i18n';
 * import type {Keysets, PartialKeysets} from '@gravity-ui/uikit/i18n';
 *
 * // add all keysets data
 * addLanguageKeysets<Keysets>('rs', {
 *     Alert: {
 *         label_close: 'Затвори',
 *         // all other keys
 *     },
 *     // all other keysets
 * });
 *
 * // add some keysets data
 * addLanguageKeysets<PartialKeysets>('rs', {
 *     Alert: {
 *         label_close: 'Затвори',
 *     },
 * });
 *
 */
export function addLanguageKeysets(language, data) {
    i18n.registerKeysets(language, data);
}
//# sourceMappingURL=addLanguageKeysets.js.map
